
Changelog
=========

0.0.0 (2021-09-25)
------------------

* First release on PyPI.
* Added 2D rendering

1.0.0 (2021-10-06)
------------------

* Added 3D rendering (not full-featured)
* Added CLI and API for 3D rendering
* Installing bpy is required for 3D rendering